OllamaProvider class

A provider for Ollama's language models.

This provider implements the LlmProvider interface to integrate Ollama's locally hosted models into the chat interface.

Implemented types
Mixed-in types

Constructors

OllamaProvider({String? baseUrl, Map<String, String>? headers, Map<String, String>? queryParams, required String model})
Creates an Ollama provider instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
history Iterable<ChatMessage>
Returns an iterable of ChatMessage objects representing the chat history.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
override
generateStream(String prompt, {Iterable<Attachment> attachments = const []}) Stream<String>
Generates a stream of text based on the given prompt and attachments. This method does not interact with a chat or build on any chat history.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
sendMessageStream(String prompt, {Iterable<Attachment> attachments = const []}) Stream<String>
Generates a stream of text based on the given prompt and attachments. Interacts with a chat and builds on the history of the chat associated with the provider.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited